==> apache-wicket-8.17.0.zip: apache-wicket-8.17.0/wicket-native-websocket/wicket-native-websocket-core/src/main/java/org/apache/wicket/protocol/ws/api/registry/ResourceNameTokenKey.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.wicket.protocol.ws.api.registry;

import java.util.Objects;

import org.apache.wicket.util.lang.Args;

/**
 * A key based on shared resource's name and a token
 */
public class ResourceNameTokenKey implements IKey
{
	private final String resourceName;
	private final String connectionToken;

	public ResourceNameTokenKey(String resourceName, String connectionToken)
	{
		this.resourceName = Args.notNull(resourceName, "resourceName");
		this.connectionToken = Args.notNull(connectionToken, "connectionToken");
	}

	@Override
	public boolean equals(Object o)
	{
		if (this == o)
			return true;
		if (o == null || getClass() != o.getClass())
			return false;
		final ResourceNameTokenKey that = (ResourceNameTokenKey)o;
		return resourceName.equals(that.resourceName) && connectionToken.equals(that.connectionToken);
	}

	@Override
	public int hashCode()
	{
		return Objects.hash(resourceName, connectionToken);
	}
}

==> apache-wicket-9.22.0.zip: apache-wicket-9.22.0/wicket-native-websocket/wicket-native-websocket-core/src/main/java/org/apache/wicket/protocol/ws/api/registry/ResourceNameTokenKey.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.wicket.protocol.ws.api.registry;

import java.util.Objects;

import org.apache.wicket.util.lang.Args;

/**
 * A key based on shared resource's name and a token
 */
public class ResourceNameTokenKey extends AbstractKey
{
	private final String resourceName;
	private final String connectionToken;


	public ResourceNameTokenKey(String resourceName, String connectionToken)
	{
		this(resourceName, connectionToken, null);
	}

	public ResourceNameTokenKey(String resourceName, String connectionToken, String context)
	{
		super(context);
		this.resourceName = Args.notNull(resourceName, "resourceName");
		this.connectionToken = Args.notNull(connectionToken, "connectionToken");
	}

	@Override
	public boolean equals(Object o)
	{
		if (this == o)
			return true;
		if (o == null || getClass() != o.getClass())
			return false;
		final ResourceNameTokenKey that = (ResourceNameTokenKey)o;
		return resourceName.equals(that.resourceName) && connectionToken.equals(that.connectionToken);
	}

	@Override
	public int hashCode()
	{
		return Objects.hash(resourceName, connectionToken);
	}
}
